---
name: 📝 Documentation
about: Request additional documentation or suggest improvements
title: "[DOC]"
labels: documentation
assignees: ''
---

* [ ] I used GitHub search to find a similar issue and didn't find what I was looking for.
* [ ] I searched the available documentation for this project via integrated search.
* [ ] I already searched in Google for what I was looking for and didn't find any information.

### Question

Who|What|Where|When|Why|How [...]?

Is it possible to [...]?

### Additional context

Add any other context or screenshots about the feature request here.
